# Texo

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Sourabh Singh from Neuroins(c) 2023

## Examples of How To Use (Buggy Alpha Version)

Predicating Sentimental Analysis in English

```python
from Texo.Sentimental.Analysis import Sentitweeten

Analysis = Sentitweeten()
Out = Analysis.Tweet_analy('Analysis this Tweet')
print(out)
```

Predicating Sentimental Analysis in Hindi

```python
from Texo.Sentimental.Analysis import Sentitweeten

Analysis = Sentitweethn()
Out = Analysis.Tweet_anal('Analysis this Tweet')
print(out)
```

